pub struct SortedScanQuery<'a, K> { /* private fields */ }Expand description
Materialized, sorted view of findings selected by a ScanQuery.
This type owns only the vector of borrowed (source, finding) pairs.
Source keys and findings remain owned by the originating
ScanResults.
Implementations
Sourceimpl<'a, K> SortedScanQuery<'a, K>
impl<'a, K> SortedScanQuery<'a, K>
Sourcepub const fn has_matches(&self) -> bool
pub const fn has_matches(&self) -> bool
Returns true when the sorted query contains at least one finding.
Sourcepub fn iter(
&self,
) -> impl DoubleEndedIterator<Item = (&'a K, &'a Finding)> + ExactSizeIterator + '_
pub fn iter( &self, ) -> impl DoubleEndedIterator<Item = (&'a K, &'a Finding)> + ExactSizeIterator + '_
Iterates over sorted (source, finding) pairs.
Sourcepub fn as_slice(&self) -> &[(&'a K, &'a Finding)]
pub fn as_slice(&self) -> &[(&'a K, &'a Finding)]
Returns the sorted findings as a borrowed slice.